#####################################################################
#                                                                   #
#   "The Clan's Reputation"                                         #
#   "Raise the Clan's Reputation"                                   #
#   "Sir Eric Rodemai in Aden Castle Town is looking                #
#   for a brave adventurer to raise the clan's reputation."         #
#   "Clan Leader, Clan Level 5 and above"                           #
#                                                                   #
#   Start NPC: Sir Eric Rodemai[30868]                              #
#                                                                   #
#   adapted for Fortress Barma, Creator                             #
#####################################################################
import sys
from l2f.gameserver.model.quest        import State
from l2f.gameserver.model.quest        import QuestState
from l2f.gameserver.model.quest        import QuestJython as JQuest
from l2f.gameserver.serverpackets      import SystemMessage
from l2f.gameserver.serverpackets      import PledgeShowInfoUpdate

qn="508_TheClansReputation"
qd="The Clans Reputation"

# Quest NPC
SIR_ERIC_RODEMAI = 30868

# Quest Items
NUCLEUS_OF_FLAMESTONE_GIANT = 8494 # Nucleus of Flamestone Giant : Nucleus obtained by defeating Flamestone Giant
THEMIS_SCALE                = 8277 # Themis' Scale : Obtain this scale by defeating Palibati Queen Themis.
NUCLEUS_OF_HEKATON_PRIME    = 8279 # Nucleus of Hekaton Prime : Nucleus obtained by defeating Hekaton Prime
TIPHON_SHARD                = 8280 # Tiphon Shard : Debris obtained by defeating Tiphon, Gargoyle Lord.
GLAKIS_NECLEUS              = 8281 # Glaki's Necleus : Nucleus obtained by defeating Glaki, the last lesser Giant.
RAHHAS_FANG                 = 8282 # Rahha's Fang : Fangs obtained by defeating Rahha.

#Quest Raid Bosses
FLAMESTONE_GIANT        = 25524
PALIBATI_QUEEN_THEMIS   = 25252
HEKATON_PRIME           = 25140
GARGOYLE_LORD_TIPHON    = 25255
LAST_LESSER_GIANT_GLAKI = 25245
RAHHA                   = 25051

# Reward
CLAN_POINTS_REWARD = 1000 # 1000 Point Per Boss

# id:[RaidBossNpcId,questItemId]
REWARDS_LIST={
    1:[PALIBATI_QUEEN_THEMIS,  THEMIS_SCALE],
    2:[HEKATON_PRIME,          NUCLEUS_OF_HEKATON_PRIME],
    3:[GARGOYLE_LORD_TIPHON,   TIPHON_SHARD],
    4:[LAST_LESSER_GIANT_GLAKI,GLAKIS_NECLEUS],
    5:[RAHHA,                  RAHHAS_FANG],
    6:[FLAMESTONE_GIANT,       NUCLEUS_OF_FLAMESTONE_GIANT]
    }

RADAR={
    1:[192346,21528,-3648],
    2:[191979,54902,-7658],
    3:[170038,-26236,-3824],
    4:[171762,55028,-5992],
    5:[117232,-9476,-3320],
    6:[144218,-5816,-4722],
    }

class Quest (JQuest) :

 def __init__(self,id,name,descr,party) : JQuest.__init__(self,id,name,descr,party)

 def onEvent (self,event,st) :
  cond = st.getInt("cond")
  htmltext=event
  if event == "30868-0.htm" :
    if cond == 0 :
      st.set("cond","1")
      st.setState(STARTED)
  elif event.isdigit() :
    if int(event) in REWARDS_LIST.keys():
      st.set("raid",event)
      htmltext="30868-"+event+".htm"
      x,y,z=RADAR[int(event)]
      if x+y+z: st.addRadar(x,y,z)
      st.playSound("ItemSound.quest_accept")
  elif event == "30868-7.htm" :
    st.playSound("ItemSound.quest_finish")
    st.exitCurrentQuest(True)
  return htmltext

 def onTalk (self,npc,st) :
  htmltext = "<html><head><body>I have nothing to say to you.</body></html>"
  npcId = npc.getNpcId()
  clan=st.getPlayer().getClan()
  
  if not st.getPlayer().getClan() :
     st.exitCurrentQuest(True)
     htmltext = "30868-0a.htm"
  elif st.getPlayer().getClan().getLeader().getPlayer() != st.getPlayer() :
     st.exitCurrentQuest(True)

     htmltext = "30868-0a.htm"
  elif st.getPlayer().getClan().getLevel() < 5 :
     st.exitCurrentQuest(True)
     htmltext =  "30868-0b.htm"
  else :
     cond = st.getInt("cond")
     raid = st.getInt("raid")
     id = st.getState()
     if id == CREATED and cond == 0 :
        htmltext =  "30868-0c.htm"
     elif id == STARTED and cond == 1 and raid in REWARDS_LIST.keys() :
        npc,item=REWARDS_LIST[raid]
        count = st.getQuestItemsCount(item)
        if not count :
           htmltext = "30868-"+str(raid)+"a.htm"
        elif count == 1 :
           htmltext = "30868-"+str(raid)+"b.htm"
           st.getPlayer().getClan().incReputation(CLAN_POINTS_REWARD)           
           st.getPlayer().getClan().broadcastToOnlineMembers(PledgeShowInfoUpdate(st.getPlayer().getClan()))
           st.getPlayer().sendPacket(SystemMessage(1777).addString(str(CLAN_POINTS_REWARD)))
           st.takeItems(item,1)
  return htmltext

 def onKill (self,npc,st) :
  if st.getPlayer().getClan().getLeader().getPlayer() == st.getPlayer() :
   id = st.getPlayer().getQuestState(qn)
  else:
    x = st.getPlayer().getClan().getLeader().getPlayer().getX();
    y = st.getPlayer().getClan().getLeader().getPlayer().getY();
    z = st.getPlayer().getClan().getLeader().getPlayer().getZ();


    dx = x - npc.getX();
    dy = y - npc.getY();
    dz = z - npc.getZ();

    if dx * dx + dy * dy + dz * dz < 1600 * 1600 :
      id = st.getPlayer().getClan().getLeader().getQuestState(qn)
  if not id : return
  if st.getInt("cond") == 1 and st.getState() == STARTED :
   raid,item = REWARDS_LIST[st.getInt("raid")]
   npcId=npc.getNpcId()
   if npcId == raid and not st.getQuestItemsCount(item) :
      st.giveItems(item,1)
      st.playSound("ItemSound.quest_middle")
  return


# Quest class and state definition
QUEST       = Quest(508,qn,qd,True)
CREATED     = State('Start',QUEST)
STARTED     = State('Started',QUEST)

QUEST.setInitialState(CREATED)

QUEST.addStartNpc(SIR_ERIC_RODEMAI)
CREATED.addTalkId(SIR_ERIC_RODEMAI)
STARTED.addTalkId(SIR_ERIC_RODEMAI)


for npc,item in REWARDS_LIST.values():
    STARTED.addKillId(npc)
    STARTED.addQuestDrop(npc,item,1)

print "importing quests: 508: "+qd
